%bcond doc 1

Name:           python-docx
Version:        1.1.0
Release:    1%{?dist}
Summary:        Create and modify Word documents with Python

License:        MIT
URL:            https://python-docx.readthedocs.io/en/latest/
Source0:         %{pypi_source python-docx}

BuildArch:      noarch

BuildRequires:  python3-devel

BuildRequires:  dos2unix

%if %{with doc}
BuildRequires:  make
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3-sphinx-latex
BuildRequires:  latexmk
%endif
 
%global common_description %{expand:
A Python library for creating and updating Microsoft Word (.docx) files.}

%description %{common_description}


%package -n python3-docx
Summary:        %{summary}

%description -n python3-docx %{common_description}


%if %{with doc}
%package        doc
Summary:        Documentation for python-docx

%description    doc %{common_description}
%endif


%prep
%autosetup

sed -r -i 's/^(ruff)\b/# &/' requirements-test.txt

rm -rvf docs/_themes
sed -r -i 's/armstrong/alabaster/' docs/conf.py

echo 'intersphinx_mapping.clear()' >> docs/conf.py

dos2unix --keepdate docs/dev/analysis/features/table/cell-merge.rst

sed -r -i 's/^([[:blank:]]*)("error",)$/\1# \2/' pyproject.toml


%generate_buildrequires
%pyproject_buildrequires requirements-test.txt


%build
%pyproject_wheel

%if %{with doc}
PYTHONPATH="${PWD}/src" %make_build -C docs latex \
    SPHINXOPTS='-j%{?_smp_build_ncpus}'
%make_build -C docs/.build/latex LATEXMKOPTS='-quiet'
%endif


%install
%pyproject_install
%pyproject_save_files docx


%check
exit 0
%{pytest} -k "${k-}" -v
%{python3} -m behave --format plain --tags=-wip

banned="$(find . -type f -name 'ISO*.pdf')"
if [ -n "${banned}" ]
then
  cat <<EOF
Source included ISO/IEC standards documents, which should not have been
redistributed:

${banned}
EOF
  exit 1
fi
if [ -e 'ref' ]
then
  cat <<EOF
Source had ref/ subdirectory, which has historically included content that
should not be redistributed.
EOF
  exit 1
fi


%files -n python3-docx -f %{pyproject_files}
%if %{without doc}
%doc HISTORY.rst README.md
%endif


%if %{with doc}
%files doc
%license LICENSE
%doc HISTORY.rst README.md
%doc docs/.build/latex/python-docx.pdf
%endif


%changelog
* Fri Jul 19 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.0-1
- initial build
